@@ -13,7 +13,8 @@ import java.net.*;
 import java.lang.reflect.*;
 
 
-class Null {
+class Null implements Serializable {
+	private static final long serialVersionUID = 2L;
 	public String toString() {
 		return "null";
 	}
