@@ -159,7 +159,19 @@ public class PrePage extends DynamicPage implements OutputNo {
 		t = left_tag.toArray( new Tag[0] );
 
 		if ( t.length == 1 )	buf = buf.append( getMethod( name, t[0] ) );
-		else	addNote( "name=" + name + "のタグは配列化されました。" );
+		else {
+			Class<?>	cls = t[0].getClass();
+			boolean	flag = true;
+			for ( int i = 1; i < t.length; i++ ) {
+				flag = t[i].getClass().equals( cls );
+				if ( !flag )	break;
+			}
+			if ( flag ) {
+				addNote( "name=" + name + "のタグは複数存在しますが、クラスが一致しているため単一インスタンス用アクセッサを生成します。" );
+				 buf = buf.append( getMethod( name, t[0] ) );
+			}
+			else	addNote( "name=" + name + "のタグは配列化されました。" );
+		}
 		buf = buf.append( getCom( name, null, null ) );
 		buf = buf.append( TAG_ARRAY );
 		FunctionInfo	info = makeFunctionInfo( TAG_ARRAY, "Tags", name );
