@@ -55,6 +55,8 @@ public class Forward implements Serializable {
 
 	Forward(){}
 
+	private StackTraceElement[]	ste403 = new StackTraceElement[0];
+
 	/**
 	 * コンストラクタ。エラーを戻す。
 	 * <br>セッションは常に解放されます。
@@ -64,10 +66,7 @@ public class Forward implements Serializable {
 		error = stat;
 		session_clear_f = true;
 		if ( stat == 403 ) {
-			System.out.println( "================ 403 Set  ==================" );
-			System.out.println( new java.util.Date().toString() );
-			Thread.dumpStack();
-			System.out.println( "============================================" );
+			ste403 = Thread.currentThread().getStackTrace();
 		}
 	}
 
@@ -247,10 +246,11 @@ public class Forward implements Serializable {
 		done_f = true;
 		if ( error != 0 ) {
 			if ( error == 403 ) {
-				Option.traceWithStack( "403 Forward" );
 				System.out.println( "================ 403 Forward  ==================" );
 				System.out.println( new java.util.Date().toString() );
-				Thread.dumpStack();
+				for ( int i = 0; i < ste403.length; i++ ) {
+					System.out.println( ste403[i].toString() );
+				}
 				System.out.println( "================================================" );
 			}
 			ErrorStatus.send( res, error );
