@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -22,7 +22,7 @@ import javax.servlet.http.*;
 /**
  * サイト制御(ファイルアップロード機能なし)。
  */
-public abstract class Supervisor extends HttpServlet {
+public abstract class Supervisor extends HttpServlet implements Cloneable {
 	class ExceptionTooLong extends Exception {
 		ExceptionTooLong( Throwable e ) {
 			super( e );
@@ -76,11 +76,15 @@ public abstract class Supervisor extends HttpServlet {
 		SandBox.doStart();
 	}
 
+	private static Supervisor org_sv = null;
 	/**
 	 * コンストラクタ。
 	 */
 	public Supervisor() {
 		super();
+		if ( org_sv == null ) {
+			org_sv = this;
+		}
 	}
 
 	private static String resolvePage( ServerInformation holder, Page from, String p, int from_key, int to_key ) {
@@ -1044,27 +1048,23 @@ public abstract class Supervisor extends HttpServlet {
 
 	protected final void doGet( HttpServletRequest req, HttpServletResponse res )  {
 		try {
-			Forward	fw = preset( RequestParameter.Method.GET, req, res );
-			if ( fw != null ) {
-				fw.Action( this, res );
-				return;
-			}
-			doAction( req, res );
-		}
-		catch( Throwable e ) {
-			onErrorDebug( e, req, res );
-		}
-		finally {
-			synchronized( data_map_th ) {
-				data_map_th.remove( Thread.currentThread() );
-				data_map_sv.remove( this );
-			}
+			Supervisor	sv = (Supervisor)clone();
+			sv.doMain( RequestParameter.Method.GET, req, res );
 		}
+		catch( CloneNotSupportedException ce ){}
 	}
 
 	protected final void doPost( HttpServletRequest req, HttpServletResponse res )  {
+		try{
+			Supervisor	sv = (Supervisor)clone();
+			sv.doMain( RequestParameter.Method.POST, req, res );
+		}
+		catch( CloneNotSupportedException ce ){}
+	}
+
+	private void doMain( RequestParameter.Method m, HttpServletRequest req, HttpServletResponse res )  {
 		try {
-			Forward	fw = preset( RequestParameter.Method.POST, req, res );
+			Forward	fw = preset( m, req, res );
 			if ( fw != null ) {
 				fw.Action( this, res );
 				return;
